@@ -27,7 +27,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"os"
 	"path/filepath"
@@ -123,7 +122,7 @@ func composerVersion() int {
 	if err != nil {
 		return DefaultComposerVersion
 	}
-	contents, err := ioutil.ReadFile(filepath.Join(cwd, "composer.lock"))
+	contents, err := os.ReadFile(filepath.Join(cwd, "composer.lock"))
 	if err != nil {
 		return DefaultComposerVersion
 	}
@@ -182,7 +181,7 @@ func downloadComposer(dir string) (string, error) {
 		return "", errors.New("signature was wrong when downloading Composer; please try again")
 	}
 	setupPath := filepath.Join(dir, "composer-setup.php")
-	ioutil.WriteFile(setupPath, installer, 0666)
+	os.WriteFile(setupPath, installer, 0666)
 
 	var stdout bytes.Buffer
 	e := &Executor{
@@ -213,7 +212,7 @@ func downloadComposerInstaller() ([]byte, error) {
 		return nil, err
 	}
 	defer resp.Body.Close()
-	return ioutil.ReadAll(resp.Body)
+	return io.ReadAll(resp.Body)
 }
 
 func downloadComposerInstallerSignature() ([]byte, error) {
@@ -222,5 +221,5 @@ func downloadComposerInstallerSignature() ([]byte, error) {
 		return nil, err
 	}
 	defer resp.Body.Close()
-	return ioutil.ReadAll(resp.Body)
+	return io.ReadAll(resp.Body)
 }
